@@ -883,6 +883,12 @@ on_save_clicked (GtkWidget *button, gpointer user_data)
 	}
 }
 
+static void 
+focus_details (GtkWidget *widget, gpointer data)
+{
+	gtk_widget_grab_focus (widget);
+}
+
 static void
 unknown_app_finished (GladeXML *xml)
 {
@@ -910,7 +916,11 @@ unknown_app_finished (GladeXML *xml)
 	                      "bug to a text file and report it to the appropriate bug tracker "
 	                      "for this application."));
 
-	gtk_widget_grab_focus (glade_xml_get_widget (xml, "details-view"));
+	/* FIXME: If we just grab the focus here to the GtkTextView it will crash on the blink_cb because
+	 * the window is nop mapped! Is this a gtk+ bug? are we doing something wrong?
+	 * Let's do a funny Workaround: */
+	g_signal_connect_after (glade_xml_get_widget (xml, "details-view"), "realize", G_CALLBACK (focus_details), NULL);
+	gtk_widget_realize (glade_xml_get_widget (xml, "details-view"));
 }
 
 static void
