@@ -59,9 +59,12 @@ enum {
 	DONE
 };
 
+enum {
+	BUG_TYPE_CRASH,
+	BUG_TYPE_REQUEST
+};
+
 
-void buddy_error (GtkWidget *parent, const char *msg, ...);
-void gdb_finished (gpointer data);
 
 
 #endif /* __bug_buddy_h__ */
