@@ -34,7 +34,6 @@
 
 #include <gnome.h>
 
-#include <libgnome/gnome-desktop-item.h>
 #include <gmenu-tree.h>
 
 #include <bonobo/bonobo-exception.h>
@@ -55,6 +54,12 @@
 	"		     'IDL:GNOME/Vertigo/PanelAppletShell:1.0']) && " \
 	"defined (panel:icon)"
 
+#define DESKTOP_ENTRY			"Desktop Entry"
+#define DESKTOP_NAME			"Name"
+#define DESKTOP_COMMENT			"Comment"
+#define DESKTOP_ICON			"Icon"
+#define DESKTOP_EXEC			"Exec"
+
 #define BUGZILLA_BUGZILLA               "X-GNOME-Bugzilla-Bugzilla"
 #define BUGZILLA_PRODUCT                "X-GNOME-Bugzilla-Product"
 #define BUGZILLA_COMPONENT              "X-GNOME-Bugzilla-Component"
@@ -66,18 +71,17 @@
 #define BA_BUGZILLA_PRODUCT             "bugzilla:product"
 #define BA_BUGZILLA_COMPONENT           "bugzilla:component"
 #define BA_BUGZILLA_VERSION             "bugzilla:version"
-#define BA_BUGZILLA_EMAIL               "bugzilla:email"
 #define BA_BUGZILLA_OTHER_BINARIES      "bugzilla:other_binaries"
 
 static void
 add_bugzilla_application (GHashTable *hash, 
 			  const char *name, 
+			  const char *cname, 
 			  const char *comment, 
 			  const char *bugzilla, 
 			  const char *product,
 			  const char *component, 
 			  const char *version, 
-			  const char *email, 
 			  const char *icon,
 			  const char *program,
 			  const char *other_programs)
@@ -89,12 +93,12 @@ add_bugzilla_application (GHashTable *hash,
 	app = g_new0 (BugzillaApplication, 1);
 	
 	app->name        = g_strdup (name);
+	app->cname       = g_strdup (cname);
 	app->comment     = g_strdup (comment);
 	app->bugzilla    = g_strdup (bugzilla);
 	app->product     = g_strdup (product);
 	app->component   = g_strdup (component);
 	app->version     = g_strdup (version);
-	app->email       = g_strdup (email);
 
 	if (icon) {
 		if (g_path_is_absolute (icon)) {
@@ -175,7 +179,7 @@ get_i18n_slist (void)
 }
 
 static void
-load_applets (GnomeIconTheme *git, GHashTable *hash)
+load_applets (GHashTable *hash)
 {
 	Bonobo_ServerInfoList *info_list;
 	Bonobo_ServerInfo *info;
@@ -219,12 +223,12 @@ NULL)) {
 
 		add_bugzilla_application (hash,
 			name,
+			bonobo_server_info_prop_lookup (info, "name", NULL),
 			bonobo_server_info_prop_lookup (info, "description", langs),
 			bonobo_server_info_prop_lookup (info, BA_BUGZILLA_BUGZILLA,  NULL),
 			bonobo_server_info_prop_lookup (info, BA_BUGZILLA_PRODUCT,   NULL),
 			bonobo_server_info_prop_lookup (info, BA_BUGZILLA_COMPONENT, NULL),
 			bonobo_server_info_prop_lookup (info, BA_BUGZILLA_VERSION, NULL),
-			bonobo_server_info_prop_lookup (info, BA_BUGZILLA_EMAIL,     NULL),
 			bonobo_server_info_prop_lookup (info, "panel:icon", NULL),
 			NULL,
 			bonobo_server_info_prop_lookup (info, BA_BUGZILLA_OTHER_BINARIES, NULL));
@@ -279,6 +283,10 @@ get_all_applications_from_dir (GMenuTreeDirectory *directory,
 	GSList *items;
 	GSList *l;
 
+	if (g_main_context_pending (NULL)) {
+		g_main_context_iteration (NULL, FALSE);
+	}
+
 	items = gmenu_tree_directory_get_contents (directory);
 	for (l = items; l; l = l->next) {
 		GMenuTreeItem *item = l->data;
@@ -346,7 +354,6 @@ bugzilla_error_quark (void)
 GHashTable *
 load_applications (void)
 {
-	GnomeIconTheme *git;
 	GSList         *all_applications;
 	GSList         *l;
 	const char     *prev_name = NULL;
@@ -354,60 +361,88 @@ load_applications (void)
 
 	GHashTable *program_to_application = g_hash_table_new (g_str_hash, g_str_equal);
 
-	git = gnome_icon_theme_new ();
-	gnome_icon_theme_set_allow_svg (git, FALSE);
-
 	all_applications = get_all_applications ();
 	for (l = all_applications; l; l = l->next) {
-		GnomeDesktopItem *ditem;
+		GKeyFile *key_file;
+		char *name;
+		char *cname;
+		char *comment;
+		char *bugzilla;
+		char *product;
+		char *component;
+		char *version;
 		char *icon;
+		char *exec;
+		char *other_binaries;
 		GMenuTreeEntry *entry = l->data;
 
+		if (g_main_context_pending (NULL)) {
+			g_main_context_iteration (NULL, FALSE);
+		}
+
 		if (prev_name && strcmp (gmenu_tree_entry_get_name (entry), prev_name) == 0) {
 			gmenu_tree_item_unref (entry);
 			continue;
 		}
-		ditem = gnome_desktop_item_new_from_uri (gmenu_tree_entry_get_desktop_file_path (entry), 
-							 0, &error);
-		if (!ditem) {
-			if (error) {
-				g_warning ("Couldn't load %s: %s", gmenu_tree_entry_get_desktop_file_path (entry),
-					   error->message);
-				g_error_free (error);
-				error = NULL;
-			}
+		key_file = g_key_file_new ();
+		g_key_file_load_from_file (key_file, gmenu_tree_entry_get_desktop_file_path (entry), 
+					   G_KEY_FILE_NONE, &error);
+		if (error) {
+			g_warning ("Couldn't load %s: %s", gmenu_tree_entry_get_desktop_file_path (entry),
+				   error->message);
+			g_error_free (error);
+			error = NULL;
 			gmenu_tree_item_unref (entry);
 			continue;
 		}
     
-		if ((gnome_desktop_item_get_entry_type (ditem) != GNOME_DESKTOP_ITEM_TYPE_APPLICATION) || !gnome_desktop_item_get_string (ditem, BUGZILLA_BUGZILLA)) {
-			gnome_desktop_item_unref (ditem);	
+		if (!g_key_file_has_group (key_file, DESKTOP_ENTRY) || !g_key_file_has_key (key_file, DESKTOP_ENTRY, BUGZILLA_BUGZILLA, &error)) {
+			g_key_file_free (key_file);	
 			gmenu_tree_item_unref (entry);
+			if (error)
+				g_error_free (error);
 			continue;
 		}
 
-		icon = gnome_desktop_item_get_icon (ditem, git);
+		name = g_key_file_get_locale_string (key_file, DESKTOP_ENTRY, DESKTOP_NAME, NULL, NULL);
+		cname = g_key_file_get_string (key_file, DESKTOP_ENTRY, DESKTOP_NAME, NULL);
+		comment = g_key_file_get_locale_string (key_file, DESKTOP_ENTRY, DESKTOP_COMMENT, NULL, NULL);
+		bugzilla = g_key_file_get_string (key_file, DESKTOP_ENTRY, BUGZILLA_BUGZILLA, NULL);
+		product = g_key_file_get_string (key_file, DESKTOP_ENTRY, BUGZILLA_PRODUCT, NULL);
+		component = g_key_file_get_string (key_file, DESKTOP_ENTRY, BUGZILLA_COMPONENT, NULL);
+		version = g_key_file_get_string (key_file, DESKTOP_ENTRY, BUGZILLA_VERSION, NULL);
+		icon = g_key_file_get_string (key_file, DESKTOP_ENTRY, DESKTOP_ICON, NULL);
+		exec = g_key_file_get_string (key_file, DESKTOP_ENTRY, DESKTOP_EXEC, NULL);
+		other_binaries = g_key_file_get_string (key_file, DESKTOP_ENTRY, BUGZILLA_OTHER_BINARIES, NULL);
+
 		add_bugzilla_application (program_to_application,
-			gnome_desktop_item_get_localestring (ditem, GNOME_DESKTOP_ITEM_NAME),
-			gnome_desktop_item_get_localestring (ditem, GNOME_DESKTOP_ITEM_COMMENT),
-			gnome_desktop_item_get_string (ditem, BUGZILLA_BUGZILLA),
-			gnome_desktop_item_get_string (ditem, BUGZILLA_PRODUCT),
-			gnome_desktop_item_get_string (ditem, BUGZILLA_COMPONENT),
-			gnome_desktop_item_get_string (ditem, BUGZILLA_VERSION),
-			gnome_desktop_item_get_string (ditem, BUGZILLA_EMAIL),
-			icon,
-			gnome_desktop_item_get_string (ditem, GNOME_DESKTOP_ITEM_EXEC),
-			gnome_desktop_item_get_string (ditem, BUGZILLA_OTHER_BINARIES));
+					  name,
+					  cname,
+					  comment,
+					  bugzilla,
+					  product,
+					  component,
+					  version,
+					  icon,
+					  exec,
+					  other_binaries);
+		g_free (name);
+		g_free (cname);
+		g_free (comment);
+		g_free (bugzilla);
+		g_free (product);
+		g_free (component);
+		g_free (version);
 		g_free (icon);
+		g_free (exec);
+		g_free (other_binaries);
 		prev_name = gmenu_tree_entry_get_name (entry);
-		gnome_desktop_item_unref (ditem);	
+		g_key_file_free (key_file);	
 		gmenu_tree_item_unref (entry);
 	}
 	g_slist_free (all_applications);
 
-	load_applets (git, program_to_application);
-
-	g_object_unref (git);
+	load_applets (program_to_application);
 
 	return program_to_application;
 }
@@ -512,18 +547,17 @@ parse_error:
 	return -1;
 }
 
-
 SoupXmlrpcMessage*
 bugzilla_create_report (BugzillaApplication *app, GnomeVersionInfo *gnome_version,
-		        const char *username, const char *text,
+		        const char *username, const char *title, const char *text,
 		        GladeXML *xml, GError **err)
 {
 	SoupXmlrpcMessage *message;
 	char *debug_string;
-	char *title;
 	char *distro;
 	char *comment;
 	char *user_agent;
+	int type;
 
 	g_return_val_if_fail (app != NULL, NULL);
 	g_return_val_if_fail (gnome_version != NULL, NULL);
@@ -590,7 +624,6 @@ bugzilla_create_report (BugzillaApplication *app, GnomeVersionInfo *gnome_versio
 
 
 	soup_xmlrpc_message_start_member (message, "short_desc");
-	title = g_strdup_printf ("crash on %s", app->name);
 	soup_xmlrpc_message_write_string (message, title); 
 	soup_xmlrpc_message_end_member (message);
 
@@ -601,11 +634,7 @@ bugzilla_create_report (BugzillaApplication *app, GnomeVersionInfo *gnome_versio
 	soup_xmlrpc_message_end_struct (message);
 
 	soup_xmlrpc_message_end_call (message);
-	debug_string = (char *)soup_xmlrpc_message_to_string (message);
-	g_print ("Message xml-rpc: %s\n", debug_string);
 	
-	g_free (title);
-
 	return message;
 
 }
